@@ -37,36 +37,12 @@ class ContrastFaceVerifyRequest(RpcRequest):
 	def set_ProductCode(self,ProductCode):
 		self.add_body_params('ProductCode', ProductCode)
 
-	def get_OssObjectName(self):
-		return self.get_body_params().get('OssObjectName')
-
-	def set_OssObjectName(self,OssObjectName):
-		self.add_body_params('OssObjectName', OssObjectName)
-
 	def get_FaceContrastPicture(self):
 		return self.get_body_params().get('FaceContrastPicture')
 
 	def set_FaceContrastPicture(self,FaceContrastPicture):
 		self.add_body_params('FaceContrastPicture', FaceContrastPicture)
 
-	def get_CertName(self):
-		return self.get_body_params().get('CertName')
-
-	def set_CertName(self,CertName):
-		self.add_body_params('CertName', CertName)
-
-	def get_Ip(self):
-		return self.get_body_params().get('Ip')
-
-	def set_Ip(self,Ip):
-		self.add_body_params('Ip', Ip)
-
-	def get_Mobile(self):
-		return self.get_body_params().get('Mobile')
-
-	def set_Mobile(self,Mobile):
-		self.add_body_params('Mobile', Mobile)
-
 	def get_DeviceToken(self):
 		return self.get_body_params().get('DeviceToken')
 
@@ -109,6 +85,36 @@ class ContrastFaceVerifyRequest(RpcRequest):
 	def set_FaceContrastPictureUrl(self,FaceContrastPictureUrl):
 		self.add_body_params('FaceContrastPictureUrl', FaceContrastPictureUrl)
 
+	def get_Model(self):
+		return self.get_query_params().get('Model')
+
+	def set_Model(self,Model):
+		self.add_query_param('Model',Model)
+
+	def get_OssObjectName(self):
+		return self.get_body_params().get('OssObjectName')
+
+	def set_OssObjectName(self,OssObjectName):
+		self.add_body_params('OssObjectName', OssObjectName)
+
+	def get_CertName(self):
+		return self.get_body_params().get('CertName')
+
+	def set_CertName(self,CertName):
+		self.add_body_params('CertName', CertName)
+
+	def get_Ip(self):
+		return self.get_body_params().get('Ip')
+
+	def set_Ip(self,Ip):
+		self.add_body_params('Ip', Ip)
+
+	def get_Mobile(self):
+		return self.get_body_params().get('Mobile')
+
+	def set_Mobile(self,Mobile):
+		self.add_body_params('Mobile', Mobile)
+
 	def get_SceneId(self):
 		return self.get_body_params().get('SceneId')
 
